# Generated by Django 3.1.5 on 2021-02-28 17:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('id_trust', '0004_miscommunication'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Interaction',
            new_name='Dialog',
        ),
    ]

    atomic = False
