# Generated by Django 3.1 on 2020-08-26 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('id_trust', '0002_auto_20180311_0154'),
    ]

    operations = [
        migrations.AddField(
            model_name='interaction',
            name='user_guess',
            field=models.CharField(blank=True, choices=[('C', 'copy cat'), ('X', 'cheat'), ('I', 'innocent'), ('G', 'grudger'), ('D', 'detective')], max_length=1),
        ),
    ]
