{% if form.errors %}errors {{ form.errors }}<p>
{% endif %}
{% if form.non_field_errors %}non_field_errors {{ form.non_field_errors }}<p>
{% endif %}
<form method="post">
    {% comment %}{ form.as_p }{% endcomment %}
    <input type="hidden" name="interaction" value={{interaction_id}} />
    <button type="submit" name="user_trust" value="true">Trust</button>
    <button type="submit" name="user_trust" value="false">Distrust</button>
    {% csrf_token %}
</form>
