# Generated by Django 2.0.2 on 2018-02-13 03:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Exchange',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_trust', models.BooleanField()),
                ('foil_trust', models.BooleanField()),
            ],
        ),
        migrations.CreateModel(
            name='Interaction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_time', models.DateTimeField()),
                ('foil_strategy', models.CharField(max_length=1)),
            ],
        ),
        migrations.AddField(
            model_name='exchange',
            name='interaction',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='id_trust.Interaction'),
        ),
    ]
