{% if interaction.user_guess or not blind %}
  the chance you are misunderstood is {{ interaction.user_miscommunication }}<br>
  the chance you misunderstand your partner is {{ interaction.foil_miscommunication }}<p>
{% endif %}
your intended trust history: {{user_intent}}<br>
{% if interaction.user_guess %}
your apparent trust history: {{user_effect}}<p>
partner's intended trust history: {{foil_intent}}<p>
{% endif %}
partner's apparent trust history: {{foil_effect}}<p>
{% if blind %}
  <form action="{% url 'id_trust:blind_interact' interaction.pk %}"
      method="post">
{% else %}
  <form action="{% url 'id_trust:reveal_interact' interaction.pk %}"
      method="post">
{% endif %}
      <button type="submit" name="user_intent" value="Trust">Trust</button>
      <button type="submit" name="user_intent" value="Distrust">Distrust</button>
      {% csrf_token %}
  </form>
<p>current score: {{interaction.score.0}} to {{interaction.score.1}}
{% if interaction.user_guess %}
  {% if interaction.user_guess == interaction.foil_strategy %}
    <p>You guessed right!: {{ interaction.get_user_guess_display }}
  {% else %}
    <p>You guessed wrong: {{ interaction.get_user_guess_display }}
    <p>(When the truth was: {{ interaction.get_foil_strategy_display }})
  {% endif %}
  <p>What percentage of the time did you act like one of the basic strategies?
    {% for j in strategy_list %}
    <br>{{j.strategy}}:
      (your partner's intent {{j.foil_intent}}%)
      (your partner appeared to you {{j.foil_effect}}%)
      (your intent {{j.user_intent}}%)
      (your appearance to your partner {{j.user_effect}}%)
    {% endfor %}
    <p>
{% else %}
  Who are you exchanging with?<p>
  <form action="{% url 'id_trust:blind_interact' interaction.pk %}"
    method="post">
    {% for value, label in strategies.choices %}
      <button type="submit" name="user_guess" value={{value}}>{{ label }}
      </button>
    {% endfor %}
    {% csrf_token %}
  </form><p>
{% endif %}
{% if interaction.user_guess %}
{% elif blind %}
  <a href="{% url 'id_trust:reveal_interact' interaction.pk %}">
    reveal the level of miscommunication
  </a><br>
{% else %}
  <a href="{% url 'id_trust:blind_interact' interaction.pk %}">
    hide the level of miscommunication
  </a><br>
{% endif %}
<a href="{% url 'id_trust:blind_home' %}">exchange with new partner</a>
