# Generated by Django 2.0.2 on 2018-03-11 01:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('id_trust', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='interaction',
            name='foil_strategy',
            field=models.CharField(choices=[('C', 'copy cat'), ('X', 'cheat'), ('I', 'innocent'), ('G', 'grudger'), ('D', 'detective')], max_length=1),
        ),
        migrations.AlterField(
            model_name='interaction',
            name='start_time',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
