{% if form.errors %}errors {{ form.errors }}<p>
{% endif %}
{% if form.non_field_errors %}non_field_errors {{ form.non_field_errors }}<p>
{% endif %}
<form method="post">
  {% if not blind %}
    <input type="range" min="0" max="1" step="0.1" value="0" name="user_miscommunication"/>
    <label for="user_miscommunication">You are misunderstood (never - always)</label>
    <br>
    <input type="range" min="0" max="1" step="0.1" value="0" name="foil_miscommunication"/>
    <label for="user_miscommunication">You misunderstand your partner (never - always)</label>
    <br>
  {% endif %}
    <button type="submit" name="user_intent" value="Trust">Trust</button>
    <button type="submit" name="user_intent" value="Distrust">Distrust</button>
    {% csrf_token %}
</form><p>
{% if blind %}
  <a href="{% url 'id_trust:reveal_home' %}">
    choose the level of miscommunication
  </a>
{% else %}
  <a href="{% url 'id_trust:blind_home' %}">
    have the level of miscommunication be assigned
  </a>
{% endif %}
